package com.dayou.configuration;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 邮件配置类
 * spring-boot-starter-mail默认只能配置一个Email信息, 考虑到以后可能多个邮件的情况, 这里换成自定义注入
 */
@Data
@Component
@ConfigurationProperties(prefix = "mail")
public class MailConfig {

    private List<MailProperties> configs;

    @Data
    public static class MailProperties {

        /**
         * host
         */
        private String host;

        /**
         * 端口
         */
        private Integer port;

        /**
         * 协议
         */
        private String protocol;

        /**
         * 密码
         */
        private String username;

        /**
         * 密码
         */
        private String password;

        /**
         * 默认编码
         */
        private String defaultEncoding;

        /**
         * smtp auth
         */
        private String auth;

        /**
         * ssl加密是否开启
         */
        private String SSLEnable;

        /**
         * ssl加密是否必须
         */
        private String SSLRequired;

    }

}

